@@ -1,3 +1,6 @@
+require 'fileutils'
+require 'gem2deb/yaml'
+
 module Gem2Deb
   class PackageNameMapping
     attr_reader :data
@@ -38,7 +41,7 @@ module Gem2Deb
 
       if update
         new_cache = cache + ".new.#{$$}"
-        if system('apt-file search /usr/share/rubygems-integration/ | grep \'.gemspec$\' > ' + new_cache)
+        if system('apt-file search /rubygems-integration/ | grep \'.gemspec$\' > ' + new_cache)
           if File.stat(new_cache).size > 0
             system('sed', '-i', '-e', 's#/.*/##; s/-[0-9.]\+.gemspec//', new_cache)
             FileUtils.mv(new_cache, cache)
@@ -68,7 +71,9 @@ module Gem2Deb
     end
 
     def get_data_from_installed_packages!
-      io = IO.popen("dpkg -S /usr/share/rubygems-integration/*/specifications/*", "r")
+      dirs = Dir["/usr/**/rubygems-integration/*/specifications"]
+      specs = dirs.map { |d| "#{d}/*" }.join(" ")
+      io = IO.popen("dpkg -S #{specs}", "r")
       @data = io.readlines.inject({}) do |memo, line|
         pkg, gemspec = line.strip.split(/:\s+/)
         pkg.gsub!(/:.*/, '')
