@@ -13,8 +13,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-Encoding.default_external = Encoding::UTF_8
-
 require 'rbconfig'
 require 'fileutils'
 require 'shellwords'
@@ -32,9 +30,15 @@ module Gem2Deb
     attr_accessor :autopkgtest
     attr_accessor :check_dependencies
     attr_accessor :check_bundler
+    attr_accessor :passed
+    attr_accessor :failed
+    attr_accessor :skipped
 
     def initialize
       @source = Gem2Deb::Source.new
+      @passed = false
+      @failed = false
+      @skipped = false
     end
 
     def load_path
@@ -81,7 +85,12 @@ module Gem2Deb
       if check_bundler
         do_check_bundler
       end
+      do_assets_smoke_test
       do_run_tests
+
+      exit(1) if self.failed
+      exit(77) if self.skipped and !self.passed
+      exit(0)
     end
 
     def do_check_dependencies
@@ -90,15 +99,12 @@ module Gem2Deb
         metadata = Gem2Deb::Metadata.new(pkg[:root])
         if metadata.gemspec
           cmd = [rubyver, '-e', 'gem "%s"' % metadata.name]
-          puts "GEM_PATH=#{gem_path} " + cmd.shelljoin
-          system({ 'GEM_PATH' => gem_path }, *cmd)
-          exitstatus = $?.exitstatus
-          if exitstatus != 0
+          run(*cmd, superficial: true) do
             system 'gem', 'list'
-            exit(1)
           end
         else
-          fail "E: dependency resolution check requested but no working gemspec available for binary package #{pkg[:binary_package]}"
+          puts "E: dependency resolution check requested but no working gemspec available for binary package #{pkg[:binary_package]}"
+          self.failed = true
         end
       end
     end
@@ -128,7 +134,8 @@ module Gem2Deb
       )
 
       if rc != 0
-        fail "E: failed to load under bundler"
+        puts "E: failed to load under bundler"
+        self.failed = true
       end
     end
 
@@ -145,7 +152,7 @@ module Gem2Deb
           puts(gemfile % metadata.name)
           puts('----------------8<----------------8<----------------8<-----------------')
           puts()
-          call(*command).tap do |rc|
+          run(*command, superficial: true).tap do |rc|
             if rc != 0
               puts "E: Command failed (exit status: #{rc})"
             end
@@ -172,13 +179,18 @@ module Gem2Deb
     end
 
     def run_rake(*args)
-      run(rubyver, '-S', 'rake', *args)
+      # Do not load rake tasks from rakelib/ which is the default
+      run(rubyver, '-S', 'rake', '--rakelibdir', '/gem2deb-nonexistent', *args)
     end
 
-    def run(program, *args)
+    def run(program, *args, superficial: false)
       exitstatus = call(program, *args)
-      exitstatus = 1 if exitstatus != 0
-      exit(exitstatus)
+      if exitstatus == 0
+        self.passed = true unless superficial
+      else
+        yield if block_given?
+        self.failed = true
+      end
     end
 
     def call(program, *args)
@@ -292,10 +304,22 @@ module Gem2Deb
       end
       def do_run_tests
         print_banner "Run tests for #{rubyver}: no test suite!"
-        exit(77) if autopkgtest
+        self.skipped = true if autopkgtest
       end
     end
 
+    def do_assets_smoke_test
+      package = @source.packages.first
+      return if !package
+      root = package[:root]
+      return unless File.directory?(File.join(root, "debian/tests/assets"))
+
+      print_banner "Running Rails assets smoke test on #{rubyver}"
+      smoke_test_script = File.join(File.dirname(__FILE__), "test_runner/assets-smoke-test.sh")
+      gem_name = Gem2Deb::Metadata.new(root).name
+      run("sh", smoke_test_script, gem_name, ruby_binary)
+    end
+
   end
 
 end
